cljs-reload.css

Discovery, change detection, and browser refresh support for stylesheets.

Discovery, change detection, and browser refresh support for stylesheets.
raw docstring

file-signatureclj

(file-signature css-paths)

Returns the content signature used to watch configured CSS files.

Returns the content signature used to watch configured CSS files.
sourceraw docstring

planclj

(plan old-snapshot new-snapshot)

Calculates changed and deleted stylesheet paths between two scans.

Calculates changed and deleted stylesheet paths between two scans.
sourceraw docstring

reload-javascriptclj

JavaScript evaluated through the active browser REPL after a CSS change.

All external stylesheet links are refreshed because filesystem paths do not have a portable one-to-one mapping to browser URLs. The old link remains active until its cache-busted replacement has loaded.

JavaScript evaluated through the active browser REPL after a CSS change.

All external stylesheet links are refreshed because filesystem paths do not
have a portable one-to-one mapping to browser URLs. The old link remains
active until its cache-busted replacement has loaded.
sourceraw docstring

scanclj

(scan css-paths)

Returns inspectable metadata for the stylesheets below css-paths.

Returns inspectable metadata for the stylesheets below `css-paths`.
sourceraw docstring

stylesheet-filesclj

(stylesheet-files css-paths)

Returns CSS files below css-paths, in stable order.

Returns CSS files below `css-paths`, in stable order.
sourceraw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries