Clojure only.

cljs-reload.repl

A thin cljs.main REPL environment that delegates to the stock browser REPL.

A thin cljs.main REPL environment that delegates to the stock browser REPL.
raw docstring

repl-envclj

(repl-env & {:as options})

Constructs a stock browser REPL decorated with cljs-reload.

All standard browser options are passed through unchanged. Reload options are :source-paths, :poll-ms, :debounce-ms, :watch?, and :verbose?.

Constructs a stock browser REPL decorated with cljs-reload.

All standard browser options are passed through unchanged. Reload options are
`:source-paths`, `:poll-ms`, `:debounce-ms`, `:watch?`, and `:verbose?`.
sourceraw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries