A thin cljs.main REPL environment that delegates to the stock browser REPL.
A thin cljs.main REPL environment that delegates to the stock browser REPL.
(repl-env & {:as options})Constructs a stock browser REPL decorated with cljs-reload.
All standard browser options are passed through unchanged. Reload options are
:source-paths, :poll-ms, :debounce-ms, :watch?, and :verbose?.
Constructs a stock browser REPL decorated with cljs-reload. All standard browser options are passed through unchanged. Reload options are `:source-paths`, `:poll-ms`, `:debounce-ms`, `:watch?`, and `:verbose?`.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |